/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *
 *   Copyright (C) 2001-2006  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 *********************************************************************/

#include "constants.h"

#include "swines.h"

/**
 ** constructor
 **
 ** @param	playerno	player who has announced the swines
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::Swines::Swines(unsigned const playerno) :
  GameplayAction(SWINES, playerno)
{
} // Swines::Swines()

/**
 ** constructor
 **
 ** @param	line	line with the data
 **
 ** @return	action corresponding to the line
 **		(to be freed)
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 ** 
 ** @todo	old format
 ** @todo	new format
 **/
GameplayAction::Swines::Swines(string line) :
  GameplayAction(SWINES, UINT_MAX)
{
#ifndef OUTDATED
  // old format in the bug report:
  //   Played: Player 2: club ace
  if (string(line, 0, strlen("Swines: ")) == "Swines: ") {
    // ToDo

    return ;
  }
#endif

  // ToDo: new format

} // GameplayAction::Swines(string line)

/**
 ** copy constructor
 **
 ** @param	swines	action to copy
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::Swines::Swines(Swines const& swines) :
  GameplayAction(swines)
{
} // Swines::Swines(Swines swines)

/**
 ** copy constructor
 **
 ** @param	swines	action to copy
 **
 ** @return	this action
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::Swines::Swines&
GameplayAction::Swines::operator=(Swines const& swines)
{
  this->GameplayAction::operator=(swines);
  return *this;
} // Swines& Swines::operator=(Swines swines)

/**
 ** destructor
 **
 ** @param	-
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::Swines::~Swines()
{
} // Swines::~Swines()

/**
 **
 ** writes the action in the output stream
 **
 ** @param	ostr	output stream
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
void
GameplayAction::Swines::write(ostream& ostr) const
{
  ostr << this->type;
  ostr << " = " << this->player;

  return ;
} // void write(ostream& ostr) const
